import {
  supportsConstructedStylesheets
} from "./chunk.JY3EKAVI.js";
import {
  __privateAdd,
  __privateGet,
  __privateMethod
} from "./chunk.SEHSDSX2.js";

// libs/core/src/components/dialog/scroll-lock.ts
import { css } from "lit";

// libs/core/src/utils/global-styles.ts
var _useLegacyStylesheets, _styleSheets, _legacyStyleSheets, _initialStyleSheets, _injectStylesLegacy, injectStylesLegacy_fn, _injectStyles, injectStyles_fn;
var _GlobalStylesRegistry = class _GlobalStylesRegistry {
  constructor() {
    __privateAdd(this, _injectStylesLegacy);
    __privateAdd(this, _injectStyles);
    __privateAdd(this, _useLegacyStylesheets, !supportsConstructedStylesheets());
    __privateAdd(this, _styleSheets, /* @__PURE__ */ new Map());
    __privateAdd(this, _legacyStyleSheets, /* @__PURE__ */ new Map());
    __privateAdd(this, _initialStyleSheets, document.adoptedStyleSheets || []);
  }
  /**
   * Get the global singleton instance of the GlobalStylesRegistry.
   */
  static get instance() {
    if (!globalThis.__gdsGlobalStylesRegistry)
      globalThis.__gdsGlobalStylesRegistry = new _GlobalStylesRegistry();
    return globalThis.__gdsGlobalStylesRegistry;
  }
  /**
   * Injects global styles into the document. This function is intended to be used for global styles
   * that cannot be scoped to a specific component.
   *
   * @param key unique identifier for this stylesheet.
   * @param styles CSSResult produced by the lit css template literal tag
   */
  injectGlobalStyles(key, styles) {
    if (__privateGet(this, _useLegacyStylesheets)) {
      const cssText = Array.isArray(styles) ? styles.map((style) => style.toString()).join("") : styles.toString();
      __privateMethod(this, _injectStylesLegacy, injectStylesLegacy_fn).call(this, key, cssText);
    } else {
      styles.styleSheet && __privateMethod(this, _injectStyles, injectStyles_fn).call(this, key, styles.styleSheet);
    }
  }
};
_useLegacyStylesheets = new WeakMap();
_styleSheets = new WeakMap();
_legacyStyleSheets = new WeakMap();
_initialStyleSheets = new WeakMap();
_injectStylesLegacy = new WeakSet();
injectStylesLegacy_fn = function(key, cssText) {
  let styleEl = __privateGet(this, _legacyStyleSheets).get(key);
  if (!styleEl) {
    styleEl = document.createElement("style");
    __privateGet(this, _legacyStyleSheets).set(key, styleEl);
  }
  styleEl.textContent = cssText;
  document.head.appendChild(styleEl);
};
_injectStyles = new WeakSet();
injectStyles_fn = function(key, styleSheet) {
  __privateGet(this, _styleSheets).set(key, styleSheet);
  document.adoptedStyleSheets = [
    ...__privateGet(this, _initialStyleSheets),
    ...Array.from(__privateGet(this, _styleSheets).values())
  ];
};
var GlobalStylesRegistry = _GlobalStylesRegistry;

// libs/core/src/components/dialog/scroll-lock.ts
var locks = /* @__PURE__ */ new Set();
function registerGlobalScrollLockStyles() {
  GlobalStylesRegistry.instance.injectGlobalStyles(
    "dialog-scroll-lock",
    css`
      .gds-scroll-lock body {
        padding-right: var(--gds-scroll-lock-size) !important;
        overflow: hidden !important;
      }
    `
  );
}
function lockBodyScrolling(lockingEl) {
  locks.add(lockingEl);
  if (!document.documentElement.classList.contains("gds-scroll-lock")) {
    const scrollbarWidth = getScrollbarWidth() + getExistingBodyPadding();
    let scrollbarGutterProperty = getComputedStyle(
      document.documentElement
    ).scrollbarGutter;
    if (!scrollbarGutterProperty || scrollbarGutterProperty === "auto") {
      scrollbarGutterProperty = "stable";
    }
    if (scrollbarWidth < 2) {
      scrollbarGutterProperty = "";
    }
    document.documentElement.style.setProperty(
      "--gds-scroll-lock-gutter",
      scrollbarGutterProperty
    );
    document.documentElement.classList.add("gds-scroll-lock");
    document.documentElement.style.setProperty(
      "--gds-scroll-lock-size",
      `${scrollbarWidth}px`
    );
  }
}
function unlockBodyScrolling(lockingEl) {
  locks.delete(lockingEl);
  if (locks.size === 0) {
    document.documentElement.classList.remove("gds-scroll-lock");
    document.documentElement.style.removeProperty("--gds-scroll-lock-size");
  }
}
function getScrollbarWidth() {
  const documentWidth = document.documentElement.clientWidth;
  return Math.abs(window.innerWidth - documentWidth);
}
function getExistingBodyPadding() {
  const padding = Number(
    getComputedStyle(document.body).paddingRight.replace(/px/, "")
  );
  if (isNaN(padding) || !padding) {
    return 0;
  }
  return padding;
}

export {
  registerGlobalScrollLockStyles,
  lockBodyScrolling,
  unlockBodyScrolling
};
